{% extends "account/base.html" %}

{% load i18n bulma_tags %}

{% block title %}{% trans "Set Password" %}{% endblock %}
{% block content_title %}<h1 class="title">{% trans "Set Password" %}</h1>{% endblock %}

{% block content %}
  <form method="POST" action="{% url 'account_set_password' %}" class="password_set">
    {% csrf_token %}
    {{ form|bulma }}
    <button type="submit" name="action" class="button is-primary">{% trans 'Set Password' %}</button>
  </form>
{% endblock %}
