{% extends "account/base.html" %}

{% load i18n account bulma_tags %}

{% block title %}{% trans "Password Reset" %}{% endblock %}
{% block content_title %}<h1 class="title">{% trans "Password Reset" %}</h1>{% endblock %}

{% block content %}
  {% if user.is_authenticated %}
    {% include "account/snippets/already_logged_in.html" %}
  {% endif %}
  <p>{% blocktrans %}We have sent you an e-mail. Please contact us if you do not receive it within a few
    minutes.{% endblocktrans %}</p>
{% endblock %}