{% extends "registration/base.html" %}
{% load i18n %}

{% block title %}{{ title }}{% endblock %}
{% block content_title %}<h1 class="title">{{ title }}</h1>{% endblock %}
{% block content %}
  <p class="content">{% trans 'Your password was changed.' %}</p>
{% endblock %}
