{% extends "account/base.html" %}

{% load i18n %}
{% block title %}{% trans "Change Password" %}{% endblock %}
{% block content_title %}<h1 class="title">{% trans "Change Password" %}</h1>{% endblock %}

{% block content %}
  <p>{% trans 'Your password is now changed.' %}</p>
{% endblock %}
