{% extends "account/base.html" %}

{% load i18n %}

{% block title %}{% trans "Account Inactive" %}{% endblock %}
{% block content_title %}<h1 class="title">{% trans "Account Inactive" %}</h1>{% endblock %}

{% block content %}
  <p>{% trans "This account is inactive." %}</p>
{% endblock %}
