{% extends "account/base.html" %}

{% load i18n %}

{% block title %}{% trans "Verify Your E-mail Address" %}{% endblock %}
{% block content_title %}{% trans "Verify Your E-mail Address" %}{% endblock %}

{% block content %}
  <p>{% blocktrans %}We have sent an e-mail to you for verification. Follow the link provided to finalize the signup
    process. Please contact us if you do not receive it within a few minutes.{% endblocktrans %}</p>
{% endblock %}