{% extends "account/base.html" %}

{% load i18n account bulma_tags %}

{% block title %}{% trans "Confirm E-mail Address" %}{% endblock %}
{% block content_title %}<h1 class="title">{% trans "Confirm E-mail Address" %}</h1>{% endblock %}

{% block content %}

  {% if confirmation %}

    {% user_display confirmation.email_address.user as user_display %}

    <p class="content">{% blocktrans with confirmation.email_address.email as email %}Please confirm that
      <a href="mailto:{{ email }}">{{ email }}</a> is an e-mail address for user {{ user_display }}.{% endblocktrans %}
    </p>

    <form method="post" action="{% url 'account_confirm_email' confirmation.key %}">
      {% csrf_token %}
      <button type="submit" class="button is-primary">{% trans 'Confirm' %}</button>
    </form>

  {% else %}

    {% url 'account_email' as email_url %}

    <p>{% blocktrans %}This e-mail confirmation link expired or is invalid. Please
      <a href="{{ email_url }}">issue a new e-mail confirmation request</a>.{% endblocktrans %}</p>

  {% endif %}

{% endblock %}