{% extends "account/base.html" %}

{% load i18n bulma_tags %}

{% block title %}{% trans "Signup" %}{% endblock %}
{% block content_title %}<h1 class="title">{% trans "Sign Up" %}</h1>{% endblock %}

{% block content %}

  <p class="content">{% blocktrans %}Already have an account? Then please <a href="{{ login_url }}">sign in</a>
    .{% endblocktrans %}</p>

  <form class="signup" id="signup_form" method="post" action="{% url 'account_signup' %}">
    {% csrf_token %}
    {{ form|bulma }}
    {% if redirect_field_value %}
      <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}"/>
    {% endif %}
    <button type="submit" class="button is-primary">{% trans "Sign Up" %}</button>
  </form>

{% endblock %}
