{% extends "account/base.html" %}

{% load i18n bulma_tags %}
{% block title %}{% trans "Change Password" %}{% endblock %}
{% block content_title %}<h1 class="title">{% if token_fail %}{% trans "Bad Token" %}{% else %}
  {% trans "Change Password" %}{% endif %}</h1>{% endblock %}
{% block content %}

  {% if token_fail %}
    {% url 'account_reset_password' as passwd_reset_url %}
    <p>{% blocktrans %}The password reset link was invalid, possibly because it has already been used.  Please request a
      <a href="{{ passwd_reset_url }}">new password reset</a>.{% endblocktrans %}</p>
  {% else %}
    {% if form %}
      <form method="POST" action="{{ action_url }}">
        {% csrf_token %}
        {{ form|bulma }}
        <button type="submit" class="button is-primary" name="action">{% trans 'change password' %}</button>
      </form>
    {% else %}
      <p>{% trans 'Your password is now changed.' %}</p>
    {% endif %}
  {% endif %}
{% endblock %}
