{% extends "registration/base.html" %}
{% load i18n %}

{% block title %}{{ title }}{% endblock %}
{% block content_title %}<h1 class="title">{{ title }}</h1>{% endblock %}

{% block content %}

  <p class="content">{% trans "Your password has been set.  You may go ahead and log in now." %}</p>

  <p><a class="button is-success" href="{% url 'login' %}">{% trans 'Log in' %}</a></p>

{% endblock %}
