{% extends "registration/base.html" %}
{% load i18n static bulma_tags %}
{% block title %}{{ title }}{% endblock %}
{% block content_title %}<h1>{{ title }}</h1>{% endblock %}

{% block content %}

  <form method="post">
    {% csrf_token %}
    <div>
      {% if form.errors %}
        <p class="errornote">
          {% if form.errors.items|length == 1 %}{% trans "Please correct the error below." %}{% else %}
            {% trans "Please correct the errors below." %}{% endif %}
        </p>
      {% endif %}

      <p>{% trans "Please enter your old password, for security's sake, and then enter your new password twice so we can verify you typed it in correctly." %}</p>

      {{ form|bulma }}
      <button type="submit" class="button is-primary">{% trans 'Change my password' %}</button>

    </div>
  </form>

{% endblock %}
