{% extends "account/base.html" %}

{% load i18n %}

{% block title %}{% trans "Sign Up Closed" %}{% endblock title %}
{% block content_title %}<h1 class="title">{% trans "Sign Up Closed" %}</h1>{% endblock %}

{% block content %}
  <p>{% trans "We are sorry, but the sign up is currently closed." %}</p>
{% endblock %}
