{% extends "account/base.html" %}

{% load i18n account bulma_tags %}

{% block title %}{% trans "Password Reset" %}{% endblock %}
{% block content_title %}<h1 class="title">{% trans "Password Reset" %}</h1>{% endblock %}

{% block content %}
  {% if user.is_authenticated %}
    {% include "account/snippets/already_logged_in.html" %}
  {% endif %}

  <p class="content">{% trans "Forgotten your password? Enter your e-mail address below, and we'll send you an e-mail allowing you to reset it." %}</p>

  <form method="POST" action="{% url 'account_reset_password' %}" class="password_reset">
    {% csrf_token %}
    {{ form|bulma }}
    <button type="submit" class="button is-primary">{% trans 'Reset My Password' %}</button>
  </form>
  <br/>
  <p>{% blocktrans %}Please contact us if you have any trouble resetting your password.{% endblocktrans %}</p>
{% endblock %}
